@@ -6,7 +6,7 @@ import pyglet
 
 from ververser.asset_manager import AssetManager, ReloadStatus
 from ververser.fps_counter import FPSCounter
-from ververser.script import load_script
+from ververser.game_script import load_script
 
 
 logger = logging.getLogger(__name__)
